/**
 * The CSS2Properties interface represents a convenience mechanism for retrieving and setting properties within a CSSStyleDeclaration. The attributes of this interface correspond to all the properties specified in CSS2. Getting an attribute of this interface is equivalent to calling the getPropertyValue method of the CSSStyleDeclaration interface. Setting an attribute of this interface is equivalent to calling the setProperty method of the CSSStyleDeclaration interface.A conformant implementation of the CSS module is not required to implement the CSS2Properties interface. If an implementation does implement this interface, the expectation is that language-specific methods can be used to cast from an instance of the CSSStyleDeclaration interface to the CSS2Properties interface.If an implementation does implement this interface, it is expected to understand the specific syntax of the shorthand properties, and apply their semantics; when the margin property is set, for example, the marginTop, marginRight, marginBottom and marginLeft properties are actually being set by the underlying implementation.When dealing with CSS "shorthand" properties, the shorthand properties should be decomposed into their component longhand properties as appropriate, and when querying for their value, the form returned should be the shortest form exactly equivalent to the declarations made in the ruleset. However, if there is no shorthand declaration that could be added to the ruleset without changing in any way the rules already declared in the ruleset (i.e., by adding longhand rules that were previously not declared in the ruleset), then the empty string should be returned for the shorthand property.For example, querying for the font property should not return "normal normal normal 14pt/normal Arial, sans-serif", when "14pt Arial, sans-serif" suffices. (The normals are initial values, and are implied by use of the longhand property.)If the values for all the longhand properties that compose a particular string are the initial values, then a string consisting of all the initial values should be returned (e.g. a border-width value of "medium" should be returned as such, not as "").For some shorthand properties that take missing values from other sides, such as the margin, padding, and border-[width|style|color] properties, the minimum number of sides possible should be used; i.e., "0px 10px" will be returned instead of "0px 10px 0px 10px".If the value of a shorthand property can not be decomposed into its component longhand properties, as is the case for the font property with a value of "menu", querying for the values of the component longhand properties should return the empty string.
 */
var CSS2Properties = {};
}
/**
 * See the line-height property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.lineHeight
 * @returns {String} 
 */
CSS2Properties.prototype.lineHeight;

/**
 * See the cursor property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.cursor
 * @returns {String} 
 */
CSS2Properties.prototype.cursor;

/**
 * See the border-right-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderRightStyle
 * @returns {String} 
 */
CSS2Properties.prototype.borderRightStyle;

/**
 * See the visibility property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.visibility
 * @returns {String} 
 */
CSS2Properties.prototype.visibility;

/**
 * See the speak-punctuation property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.speakPunctuation
 * @returns {String} 
 */
CSS2Properties.prototype.speakPunctuation;

/**
 * See the font-variant property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontVariant
 * @returns {String} 
 */
CSS2Properties.prototype.fontVariant;

/**
 * See the background-attachment property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.backgroundAttachment
 * @returns {String} 
 */
CSS2Properties.prototype.backgroundAttachment;

/**
 * See the pause-before property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pauseBefore
 * @returns {String} 
 */
CSS2Properties.prototype.pauseBefore;

/**
 * See the cue property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.cue
 * @returns {String} 
 */
CSS2Properties.prototype.cue;

/**
 * See the text-decoration property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.textDecoration
 * @returns {String} 
 */
CSS2Properties.prototype.textDecoration;

/**
 * See the float property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.cssFloat
 * @returns {String} 
 */
CSS2Properties.prototype.cssFloat;

/**
 * See the page property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.page
 * @returns {String} 
 */
CSS2Properties.prototype.page;

/**
 * See the margin property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.margin
 * @returns {String} 
 */
CSS2Properties.prototype.margin;

/**
 * See the border property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.border
 * @returns {String} 
 */
CSS2Properties.prototype.border;

/**
 * See the right property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.right
 * @returns {String} 
 */
CSS2Properties.prototype.right;

/**
 * See the border-spacing property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderSpacing
 * @returns {String} 
 */
CSS2Properties.prototype.borderSpacing;

/**
 * See the list-style-position property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.listStylePosition
 * @returns {String} 
 */
CSS2Properties.prototype.listStylePosition;

/**
 * See the padding-top property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.paddingTop
 * @returns {String} 
 */
CSS2Properties.prototype.paddingTop;

/**
 * See the pitch-range property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pitchRange
 * @returns {String} 
 */
CSS2Properties.prototype.pitchRange;

/**
 * See the border-bottom property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderBottom
 * @returns {String} 
 */
CSS2Properties.prototype.borderBottom;

/**
 * See the font-size property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontSize
 * @returns {String} 
 */
CSS2Properties.prototype.fontSize;

/**
 * See the padding-left property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.paddingLeft
 * @returns {String} 
 */
CSS2Properties.prototype.paddingLeft;

/**
 * See the content property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.content
 * @returns {String} 
 */
CSS2Properties.prototype.content;

/**
 * See the font-weight property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontWeight
 * @returns {String} 
 */
CSS2Properties.prototype.fontWeight;

/**
 * See the outline-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.outlineWidth
 * @returns {String} 
 */
CSS2Properties.prototype.outlineWidth;

/**
 * See the min-height property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.minHeight
 * @returns {String} 
 */
CSS2Properties.prototype.minHeight;

/**
 * See the border-top property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderTop
 * @returns {String} 
 */
CSS2Properties.prototype.borderTop;

/**
 * See the border-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderWidth
 * @returns {String} 
 */
CSS2Properties.prototype.borderWidth;

/**
 * See the bottom property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.bottom
 * @returns {String} 
 */
CSS2Properties.prototype.bottom;

/**
 * See the border-right-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderRightWidth
 * @returns {String} 
 */
CSS2Properties.prototype.borderRightWidth;

/**
 * See the position property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.position
 * @returns {String} 
 */
CSS2Properties.prototype.position;

/**
 * See the border-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderColor
 * @returns {String} 
 */
CSS2Properties.prototype.borderColor;

/**
 * See the outline property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.outline
 * @returns {String} 
 */
CSS2Properties.prototype.outline;

/**
 * See the marker-offset property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.markerOffset
 * @returns {String} 
 */
CSS2Properties.prototype.markerOffset;

/**
 * See the unicode-bidi property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.unicodeBidi
 * @returns {String} 
 */
CSS2Properties.prototype.unicodeBidi;

/**
 * See the vertical-align property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.verticalAlign
 * @returns {String} 
 */
CSS2Properties.prototype.verticalAlign;

/**
 * See the caption-side property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.captionSide
 * @returns {String} 
 */
CSS2Properties.prototype.captionSide;

/**
 * See the clear property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.clear
 * @returns {String} 
 */
CSS2Properties.prototype.clear;

/**
 * See the speech-rate property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.speechRate
 * @returns {String} 
 */
CSS2Properties.prototype.speechRate;

/**
 * See the richness property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.richness
 * @returns {String} 
 */
CSS2Properties.prototype.richness;

/**
 * See the border-left-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderLeftWidth
 * @returns {String} 
 */
CSS2Properties.prototype.borderLeftWidth;

/**
 * See the left property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.left
 * @returns {String} 
 */
CSS2Properties.prototype.left;

/**
 * See the font-family property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontFamily
 * @returns {String} 
 */
CSS2Properties.prototype.fontFamily;

/**
 * See the padding-bottom property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.paddingBottom
 * @returns {String} 
 */
CSS2Properties.prototype.paddingBottom;

/**
 * See the cue-after property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.cueAfter
 * @returns {String} 
 */
CSS2Properties.prototype.cueAfter;

/**
 * See the page-break-inside property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pageBreakInside
 * @returns {String} 
 */
CSS2Properties.prototype.pageBreakInside;

/**
 * See the elevation property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.elevation
 * @returns {String} 
 */
CSS2Properties.prototype.elevation;

/**
 * See the speak property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.speak
 * @returns {String} 
 */
CSS2Properties.prototype.speak;

/**
 * See the font-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontStyle
 * @returns {String} 
 */
CSS2Properties.prototype.fontStyle;

/**
 * See the list-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.listStyle
 * @returns {String} 
 */
CSS2Properties.prototype.listStyle;

/**
 * See the padding-right property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.paddingRight
 * @returns {String} 
 */
CSS2Properties.prototype.paddingRight;

/**
 * See the margin-bottom property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.marginBottom
 * @returns {String} 
 */
CSS2Properties.prototype.marginBottom;

/**
 * See the orphans property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.orphans
 * @returns {String} 
 */
CSS2Properties.prototype.orphans;

/**
 * See the outline-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.outlineStyle
 * @returns {String} 
 */
CSS2Properties.prototype.outlineStyle;

/**
 * See the background property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.background
 * @returns {String} 
 */
CSS2Properties.prototype.background;

/**
 * See the volume property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.volume
 * @returns {String} 
 */
CSS2Properties.prototype.volume;

/**
 * See the page-break-after property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pageBreakAfter
 * @returns {String} 
 */
CSS2Properties.prototype.pageBreakAfter;

/**
 * See the border-bottom-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderBottomStyle
 * @returns {String} 
 */
CSS2Properties.prototype.borderBottomStyle;

/**
 * See the background-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.backgroundColor
 * @returns {String} 
 */
CSS2Properties.prototype.backgroundColor;

/**
 * See the margin-left property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.marginLeft
 * @returns {String} 
 */
CSS2Properties.prototype.marginLeft;

/**
 * See the marks property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.marks
 * @returns {String} 
 */
CSS2Properties.prototype.marks;

/**
 * See the min-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.minWidth
 * @returns {String} 
 */
CSS2Properties.prototype.minWidth;

/**
 * See the border-left-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderLeftStyle
 * @returns {String} 
 */
CSS2Properties.prototype.borderLeftStyle;

/**
 * See the border-top-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderTopStyle
 * @returns {String} 
 */
CSS2Properties.prototype.borderTopStyle;

/**
 * See the speak-header property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.speakHeader
 * @returns {String} 
 */
CSS2Properties.prototype.speakHeader;

/**
 * See the border-left property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderLeft
 * @returns {String} 
 */
CSS2Properties.prototype.borderLeft;

/**
 * See the padding property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.padding
 * @returns {String} 
 */
CSS2Properties.prototype.padding;

/**
 * See the border-collapse property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderCollapse
 * @returns {String} 
 */
CSS2Properties.prototype.borderCollapse;

/**
 * See the pause property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pause
 * @returns {String} 
 */
CSS2Properties.prototype.pause;

/**
 * See the height property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.height
 * @returns {String} 
 */
CSS2Properties.prototype.height;

/**
 * See the max-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.maxWidth
 * @returns {String} 
 */
CSS2Properties.prototype.maxWidth;

/**
 * See the border-right property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderRight
 * @returns {String} 
 */
CSS2Properties.prototype.borderRight;

/**
 * See the white-space property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.whiteSpace
 * @returns {String} 
 */
CSS2Properties.prototype.whiteSpace;

/**
 * See the widows property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.widows
 * @returns {String} 
 */
CSS2Properties.prototype.widows;

/**
 * See the letter-spacing property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.letterSpacing
 * @returns {String} 
 */
CSS2Properties.prototype.letterSpacing;

/**
 * See the margin-top property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.marginTop
 * @returns {String} 
 */
CSS2Properties.prototype.marginTop;

/**
 * See the font property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.font
 * @returns {String} 
 */
CSS2Properties.prototype.font;

/**
 * See the background-repeat property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.backgroundRepeat
 * @returns {String} 
 */
CSS2Properties.prototype.backgroundRepeat;

/**
 * See the width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.width
 * @returns {String} 
 */
CSS2Properties.prototype.width;

/**
 * See the empty-cells property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.emptyCells
 * @returns {String} 
 */
CSS2Properties.prototype.emptyCells;

/**
 * See the stress property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.stress
 * @returns {String} 
 */
CSS2Properties.prototype.stress;

/**
 * See the background-image property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.backgroundImage
 * @returns {String} 
 */
CSS2Properties.prototype.backgroundImage;

/**
 * See the display property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.display
 * @returns {String} 
 */
CSS2Properties.prototype.display;

/**
 * See the size property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.size
 * @returns {String} 
 */
CSS2Properties.prototype.size;

/**
 * See the border-left-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderLeftColor
 * @returns {String} 
 */
CSS2Properties.prototype.borderLeftColor;

/**
 * See the overflow property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.overflow
 * @returns {String} 
 */
CSS2Properties.prototype.overflow;

/**
 * See the max-height property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.maxHeight
 * @returns {String} 
 */
CSS2Properties.prototype.maxHeight;

/**
 * See the azimuth property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.azimuth
 * @returns {String} 
 */
CSS2Properties.prototype.azimuth;

/**
 * See the word-spacing property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.wordSpacing
 * @returns {String} 
 */
CSS2Properties.prototype.wordSpacing;

/**
 * See the list-style-type property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.listStyleType
 * @returns {String} 
 */
CSS2Properties.prototype.listStyleType;

/**
 * See the pitch property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pitch
 * @returns {String} 
 */
CSS2Properties.prototype.pitch;

/**
 * See the border-right-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderRightColor
 * @returns {String} 
 */
CSS2Properties.prototype.borderRightColor;

/**
 * See the border-style property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderStyle
 * @returns {String} 
 */
CSS2Properties.prototype.borderStyle;

/**
 * See the z-index property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.zIndex
 * @returns {String} 
 */
CSS2Properties.prototype.zIndex;

/**
 * See the counter-increment property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.counterIncrement
 * @returns {String} 
 */
CSS2Properties.prototype.counterIncrement;

/**
 * See the border-bottom-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderBottomColor
 * @returns {String} 
 */
CSS2Properties.prototype.borderBottomColor;

/**
 * See the direction property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.direction
 * @returns {String} 
 */
CSS2Properties.prototype.direction;

/**
 * See the table-layout property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.tableLayout
 * @returns {String} 
 */
CSS2Properties.prototype.tableLayout;

/**
 * See the cue-before property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.cueBefore
 * @returns {String} 
 */
CSS2Properties.prototype.cueBefore;

/**
 * See the text-indent property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.textIndent
 * @returns {String} 
 */
CSS2Properties.prototype.textIndent;

/**
 * See the background-position property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.backgroundPosition
 * @returns {String} 
 */
CSS2Properties.prototype.backgroundPosition;

/**
 * See the counter-reset property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.counterReset
 * @returns {String} 
 */
CSS2Properties.prototype.counterReset;

/**
 * See the text-transform property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.textTransform
 * @returns {String} 
 */
CSS2Properties.prototype.textTransform;

/**
 * See the text-align property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.textAlign
 * @returns {String} 
 */
CSS2Properties.prototype.textAlign;

/**
 * See the border-top-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderTopWidth
 * @returns {String} 
 */
CSS2Properties.prototype.borderTopWidth;

/**
 * See the top property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.top
 * @returns {String} 
 */
CSS2Properties.prototype.top;

/**
 * See the clip property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.clip
 * @returns {String} 
 */
CSS2Properties.prototype.clip;

/**
 * See the margin-right property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.marginRight
 * @returns {String} 
 */
CSS2Properties.prototype.marginRight;

/**
 * See the border-top-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderTopColor
 * @returns {String} 
 */
CSS2Properties.prototype.borderTopColor;

/**
 * See the page-break-before property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pageBreakBefore
 * @returns {String} 
 */
CSS2Properties.prototype.pageBreakBefore;

/**
 * See the outline-color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.outlineColor
 * @returns {String} 
 */
CSS2Properties.prototype.outlineColor;

/**
 * See the voice-family property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.voiceFamily
 * @returns {String} 
 */
CSS2Properties.prototype.voiceFamily;

/**
 * See the pause-after property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.pauseAfter
 * @returns {String} 
 */
CSS2Properties.prototype.pauseAfter;

/**
 * See the speak-numeral property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.speakNumeral
 * @returns {String} 
 */
CSS2Properties.prototype.speakNumeral;

/**
 * See the quotes property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.quotes
 * @returns {String} 
 */
CSS2Properties.prototype.quotes;

/**
 * See the color property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.color
 * @returns {String} 
 */
CSS2Properties.prototype.color;

/**
 * See the text-shadow property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.textShadow
 * @returns {String} 
 */
CSS2Properties.prototype.textShadow;

/**
 * See the font-size-adjust property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontSizeAdjust
 * @returns {String} 
 */
CSS2Properties.prototype.fontSizeAdjust;

/**
 * See the border-bottom-width property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.borderBottomWidth
 * @returns {String} 
 */
CSS2Properties.prototype.borderBottomWidth;

/**
 * See the list-style-image property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.listStyleImage
 * @returns {String} 
 */
CSS2Properties.prototype.listStyleImage;

/**
 * See the font-stretch property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.fontStretch
 * @returns {String} 
 */
CSS2Properties.prototype.fontStretch;

/**
 * See the play-during property definition in CSS2. Exceptions on setting DOMException SYNTAX_ERR: Raised if the new value has a syntax error and is unparsable. NO_MODIFICATION_ALLOWED_ERR: Raised if this property is readonly.
 * @syntax cSS2Properties.playDuring
 * @returns {String} 
 */
CSS2Properties.prototype.playDuring;

/**
 * Represents the CSS2Properties prototype object.
 * @syntax CSS2Properties.prototype
 * @static
 */
CSS2Properties.prototype;

